import { Button } from "@/components/ui/button";
import { Printer } from "lucide-react";
import { useTranslations } from "next-intl";
import Image from "next/image";
import { useRef } from "react";
import { useReactToPrint } from "react-to-print";

interface InvoiceDetailsProps {
	orderInfo: {
		id: number;
		payment_status: string;
		status: string;
		first_name: string;
		middle_name: string;
		last_name: string;
		phone: string;
		city: { name: string };
		area: { name: string };
		address: string;
		subtotal: number;
		delivery_price: number;
		vat_value: number;
		total_price: number;
	};
}

function InvoiceDetails({ orderInfo }: InvoiceDetailsProps) {
	const t = useTranslations("Cart");
	const printRef = useRef<HTMLDivElement>(null);

	const handlePrint = useReactToPrint({
		contentRef: printRef,
		documentTitle: `Invoice-${orderInfo.id}`,
		pageStyle: `
			@page {
				size: portrait;
			}
			@media print {
				body * {
					visibility: hidden;
				}
				#print-content, #print-content * {
					visibility: visible;
				}
				#print-content {
					position: absolute;
					left: 0;
					top: 0;
					width: 100%;
					height: 100%;
					background: white;
				}
			}
		`
	});

	return (
		<div>
			<div className="flex justify-end mb-4">
				<Button onClick={handlePrint} variant="outline" size="sm">
					<Printer className="w-4 h-4" />
				</Button>
			</div>
			<div id="print-content" ref={printRef}>
				{/* Product Details */}
				<div className="print-section border border-green-600 bg-[#92e07a1c] rounded-lg p-4 mb-6">
					<div className="flex justify-between items-center mb-4">
						<h2 className="font-semibold">حالة الدفع</h2>
						<div className="text-gray-600">{t(orderInfo?.payment_status)}</div>
					</div>

					<div className="flex justify-between items-center mb-4">
						<h2 className="font-semibold">حالة الطلب</h2>
						<div className="text-gray-600">{t(orderInfo?.status)}</div>
					</div>
				</div>

				{/* Delivery Details */}
				<div className="print-section border border-green-600 bg-[#92e07a1c] rounded-lg p-4 mb-6" dir="rtl">
					<h3 className="font-semibold mb-3 text-right">تفاصيل التوصيل</h3>
					<div className="space-y-2 text-right">
						<p>الاسم: {orderInfo?.first_name} {orderInfo?.middle_name} {orderInfo?.last_name}</p>
						<p>رقم هاتف: <span className="text-end">{orderInfo?.phone}</span></p>
						<p>المدينة: {orderInfo?.city?.name}</p>
						<p>المنطقة: {orderInfo?.area?.name}</p>
						<p>عنوان: {orderInfo?.address}</p>
					</div>
				</div>

				{/* Price Details */}
				<div className="print-section border border-green-600 bg-[#92e07a1c] rounded-lg p-4 mb-6" dir="rtl">
					<h3 className="font-semibold mb-3 text-right">تفاصيل السعر</h3>
					<div className="space-y-2">
						<div className="flex justify-between">
							<div className="flex items-center gap-2">
								<span>{orderInfo?.subtotal?.toFixed(2)}</span>
								<Image
									src={"/coins/Saudi_Riyal.jpg"}
									alt="Saudi_Riyal"
									width={12}
									height={12}
								/>
							</div>
							<span>سعر المنتج</span>
						</div>
						<div className="flex justify-between">
							<div className="flex items-center gap-2">
								<span>{orderInfo?.delivery_price?.toFixed(2)}</span>
								<Image
									src={"/coins/Saudi_Riyal.jpg"}
									alt="Saudi_Riyal"
									width={12}
									height={12}
								/>
							</div>
							<span>كلفة توصيل</span>
						</div>
						<div className="flex justify-between">
							<div className="flex items-center gap-2">
								<span>{orderInfo?.vat_value?.toFixed(2)}</span>
								<Image
									src={"/coins/Saudi_Riyal.jpg"}
									alt="Saudi_Riyal"
									width={12}
									height={12}
								/>
							</div>
							<span>الضرائب</span>
						</div>
						<div className="flex justify-between pt-2 border-t font-semibold">
							<div className="flex items-center gap-2">
								<span>{orderInfo?.total_price}</span>
								<Image
									src={"/coins/Saudi_Riyal.jpg"}
									alt="Saudi_Riyal"
									width={12}
									height={12}
								/>
							</div>
							<span>الكلي</span>
						</div>
					</div>
				</div>
			</div>
		</div>
	);
}

export default InvoiceDetails;
